@@ -4,7 +4,7 @@ use 5.010001;
 
 use Pod::Weaver::Config::Assembler;
 
-our $VERSION = '0.11'; # VERSION
+our $VERSION = '0.12'; # VERSION
 
 sub _exp { Pod::Weaver::Config::Assembler->expand_package($_[0]) }
 
@@ -12,8 +12,7 @@ sub mvp_bundle_config {
     return (
         [ '@Author::SHARYANTO/CorePrep', _exp('@CorePrep'), {} ],
         [ '@Author::SHARYANTO/Name', _exp('Name'), {} ],
-        [ '@Author::SHARYANTO/Version', _exp('Version'), {} ],
-        [ '@Author::SHARYANTO/ReleaseDate', _exp('ReleaseDate'), {} ],
+        [ '@Author::SHARYANTO/Version', _exp('Version'), {format=>'This document describes version %v of module %m (in distribution %r), released on %{YYYY-MM-dd}d.'} ],
         [ '@Author::SHARYANTO/prelude', _exp('Region'), { region_name => 'prelude' } ],
 
         [ 'SYNOPSIS', _exp('Generic'), {} ],
@@ -57,11 +56,7 @@ Pod::Weaver::PluginBundle::Author::SHARYANTO - SHARYANTO's default Pod::Weaver c
 
 =head1 VERSION
 
-version 0.11
-
-=head1 RELEASE DATE
-
-2014-04-23
+This document describes version 0.12 of module Pod::Weaver::PluginBundle::Author::SHARYANTO (in distribution Pod-Weaver-PluginBundle-Author-SHARYANTO), released on 2014-04-28.
 
 =head1 SYNOPSIS
 
